
:autogenerated:

krotov.second_order module
==========================

.. currentmodule:: krotov.second_order

.. automodule:: krotov.second_order
    :members: Sigma, numerical_estimate_A
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Classes:

    .. autosummary::
        :nosignatures:

        Sigma

    Functions:

    .. autosummary::
        :nosignatures:

        numerical_estimate_A





    ``__all__``: :class:`Sigma <krotov.second_order.Sigma>`, :func:`numerical_estimate_A <krotov.second_order.numerical_estimate_A>`



    Reference
    ---------